@@ -37,6 +37,10 @@
 #include <QDockWidget>
 #include <QInputDialog>
 #include <QMessageBox>
+#include <QtGlobal>
+#if QT_VERSION >= QT_VERSION_CHECK(5, 15, 0)
+    #include <QPainterPath>
+#endif
 #include <QPainter>
 #include <QSettings>
 #include <QTextDocument>
@@ -79,6 +83,7 @@ const QString SPLITVIEWWIDGET_LOADING_TEXT = "Loading...";
 // Activate this if you want to know when which item is triggered to load and draw
 #define SPLITVIEWWIDGET_DEBUG_LOAD_DRAW 0
 #if SPLITVIEWWIDGET_DEBUG_LOAD_DRAW && !NDEBUG
+#include <QDebug>
 #define DEBUG_LOAD_DRAW(fmt) qDebug() << fmt
 #else
 #define DEBUG_LOAD_DRAW(fmt) ((void)0)
@@ -87,6 +92,8 @@ const QString SPLITVIEWWIDGET_LOADING_TEXT = "Loading...";
 splitViewWidget::splitViewWidget(QWidget *parent)
   : MoveAndZoomableView(parent)
 {
+  paletteBackgroundColorSettingsTag = "View/BackgroundColor";
+
   setFocusPolicy(Qt::NoFocus);
   setViewSplitMode(DISABLED);
   updateSettings();
@@ -117,13 +124,9 @@ void splitViewWidget::updateSettings()
 {
   MoveAndZoomableView::updateSettings();
 
-  // Update the palette in the next draw event.
-  // We don't do this here because Qt overwrites the setting if the theme is changed.
-  paletteNeedsUpdate = true;
-
   // Get the color of the regular grid
   QSettings settings;
-  regularGridColor = settings.value("OverlayGrid/Color").value<QColor>();
+  regularGridColor = settings.value("View/GridColor").value<QColor>();
 
   // Load the split line style from the settings and set it
   QString splittingStyleString = settings.value("SplitViewLineStyle").toString();
@@ -132,7 +135,7 @@ void splitViewWidget::updateSettings()
   else
     splittingLineStyle = SOLID_LINE;
 
-  zoomBoxBackgroundColor = settings.value("Background/Color").value<QColor>();
+  zoomBoxBackgroundColor = settings.value(paletteBackgroundColorSettingsTag).value<QColor>();
   drawItemPathAndNameEnabled = settings.value("ShowFilePathInSplitMode", true).toBool();
 
   // Something about how we draw might have been changed
@@ -143,17 +146,7 @@ void splitViewWidget::paintEvent(QPaintEvent *paint_event)
 {
   Q_UNUSED(paint_event);
 
-  if (paletteNeedsUpdate)
-  {
-    // load the background color from settings and set it
-    QPalette Pal(palette());
-    QSettings settings;
-    QColor bgColor = settings.value("Background/Color").value<QColor>();
-    Pal.setColor(QPalette::Background, bgColor);
-    setAutoFillBackground(true);
-    setPalette(Pal);
-    paletteNeedsUpdate = false;
-  }
+  MoveAndZoomableView::updatePaletteIfNeeded();
 
   if (!playlist)
     // The playlist was not initialized yet. Nothing to draw (yet)
@@ -267,7 +260,7 @@ void splitViewWidget::paintEvent(QPaintEvent *paint_event)
     const bool drawItemNames = (drawItemPathAndNameEnabled && 
                                 item[0] != nullptr && item[1] != nullptr &&
                                 !itemNamesToDraw.first.isEmpty() && !itemNamesToDraw.second.isEmpty() &&
-                                item[0]->isFileSource() && item[1]->isFileSource());
+                                item[0]->properties().isFileSource && item[1]->properties().isFileSource);
 
     // Draw two items (or less, if less items are selected)
     if (item[0])
@@ -528,7 +521,7 @@ void splitViewWidget::updatePixelPositions()
     const bool mouseInLeftOrRightView = (isSplitting() && (this->zoomBoxMousePosition.x() > xSplit));
 
     // The absolute center point of the item under the cursor
-    const QPoint itemCenterMousePos = (mouseInLeftOrRightView) ? centerPoints[1] + this->moveOffset : centerPoints[0] + this->moveOffset;
+    const auto itemCenterMousePos = (mouseInLeftOrRightView) ? centerPoints[1] + this->moveOffset : centerPoints[0] + this->moveOffset;
 
     // The difference in the item under the mouse (normalized by zoom factor)
     double diffInItem[2] = {(double)(itemCenterMousePos.x() - this->zoomBoxMousePosition.x()) / this->zoomFactor + 0.5,
@@ -742,7 +735,7 @@ void splitViewWidget::paintRegularGrid(QPainter *painter, playlistItem *item)
   }
 }
 
-void splitViewWidget::paintPixelRulersX(QPainter &painter, playlistItem *item, int xPixMin, int xPixMax, double zoom, QPoint centerPoints, QPoint offset)
+void splitViewWidget::paintPixelRulersX(QPainter &painter, playlistItem *item, int xPixMin, int xPixMax, double zoom, QPoint centerPoints, QPointF offset)
 {
   if (zoom < 32)
     return;
@@ -754,7 +747,7 @@ void splitViewWidget::paintPixelRulersX(QPainter &painter, playlistItem *item, i
   // Get the pixel values that are visible on screen
   QSize frameSize = item->getSize();
   QSize videoRect = frameSize * zoom;
-  QPoint worldTransform = centerPoints + offset;
+  auto worldTransform = centerPoints + offset;
   int xMin = (videoRect.width() / 2 - worldTransform.x() - xPixMin) / zoom;
   int xMax = (videoRect.width() / 2 - (worldTransform.x() - xPixMax)) / zoom;
   xMin = clip(xMin, 0, frameSize.width());
@@ -790,7 +783,7 @@ void splitViewWidget::paintPixelRulersX(QPainter &painter, playlistItem *item, i
   }
 }
 
-void splitViewWidget::paintPixelRulersY(QPainter &painter, playlistItem *item, int yPixMax, int xPos, double zoom, QPoint centerPoints, QPoint offset)
+void splitViewWidget::paintPixelRulersY(QPainter &painter, playlistItem *item, int yPixMax, int xPos, double zoom, QPoint centerPoints, QPointF offset)
 {
   if (zoom < 32)
     return;
@@ -801,7 +794,7 @@ void splitViewWidget::paintPixelRulersY(QPainter &painter, playlistItem *item, i
 
   QSize frameSize = item->getSize();
   QSize videoRect = frameSize * zoom;
-  QPoint worldTransform = centerPoints + offset;
+  auto worldTransform = centerPoints + offset;
 
   // Get the pixel values that are visible on screen
   int yMin = (videoRect.height() / 2 - worldTransform.y()) / zoom;
@@ -951,7 +944,7 @@ void splitViewWidget::wheelEvent (QWheelEvent *event)
     MoveAndZoomableView::wheelEvent(event);
 }
 
-void splitViewWidget::setMoveOffset(QPoint offset)
+void splitViewWidget::setMoveOffset(QPointF offset)
 {
   MoveAndZoomableView::setMoveOffset(offset);
 
@@ -963,7 +956,7 @@ void splitViewWidget::setMoveOffset(QPoint offset)
     {
       if (item[i])
       {
-        DEBUG_LOAD_DRAW("splitViewWidget::setMoveOffset item " << item[i]->getID() << " (" << offset.x() << "," << offset.y() << ")");
+        DEBUG_LOAD_DRAW("splitViewWidget::setMoveOffset item " << item[i]->properties().id << " (" << offset.x() << "," << offset.y() << ")");
         item[i]->saveCenterOffset(this->moveOffset, !isMasterView);
         item[i]->saveCenterOffset(this->getOtherWidget()->moveOffset, isMasterView);
       }
@@ -971,7 +964,7 @@ void splitViewWidget::setMoveOffset(QPoint offset)
   }
 }
 
-QPoint splitViewWidget::getMoveOffsetCoordinateSystemOrigin(const QPoint zoomPoint) const
+QPoint splitViewWidget::getMoveOffsetCoordinateSystemOrigin(const QPointF zoomPoint) const
 {
   if (viewSplitMode == SIDE_BY_SIDE)
   {
@@ -994,11 +987,15 @@ QPoint splitViewWidget::getMoveOffsetCoordinateSystemOrigin(const QPoint zoomPoi
     return QWidget::rect().center();
 }
 
-void splitViewWidget::onZoomRectUpdateOffsetAndZoom(QRect zoomRect, double additionalZoomFactor)
+void splitViewWidget::onZoomRectUpdateOffsetAndZoom(QRectF zoomRect, double additionalZoomFactor)
 {
-  const QPoint zoomRectCenterOffset = zoomRect.center() - this->getMoveOffsetCoordinateSystemOrigin(this->viewZoomingMousePosStart);
+  const auto newZoom = this->zoomFactor * additionalZoomFactor;
+  if (newZoom < ZOOMINGLIMIT.min || newZoom > ZOOMINGLIMIT.max)
+    return;
+
+  const auto zoomRectCenterOffset = zoomRect.center() - this->getMoveOffsetCoordinateSystemOrigin(this->viewZoomingMousePosStart);
   this->setMoveOffset((this->moveOffset - zoomRectCenterOffset) * additionalZoomFactor);
-  this->setZoomFactor(this->zoomFactor * additionalZoomFactor);
+  this->setZoomFactor(newZoom);
 }
 
 void splitViewWidget::setSplittingPoint(double point, bool setLinkedViews)
@@ -1022,7 +1019,7 @@ void splitViewWidget::setZoomFactor(double zoom)
     {
       if (item[i])
       {
-        DEBUG_LOAD_DRAW("splitViewWidget::setthis->getZoomFactor() item " << item[0]->getID() << " (" << zoom << ")");
+        DEBUG_LOAD_DRAW("splitViewWidget::setthis->getZoomFactor() item " << item[0]->properties().id << " (" << zoom << ")");
         item[i]->saveZoomFactor(this->zoomFactor, !this->isMasterView);
         item[i]->saveZoomFactor(this->getOtherWidget()->zoomFactor, this->isMasterView);
       }
@@ -1111,22 +1108,27 @@ void splitViewWidget::toggleSeparateWindow(bool checked)
   emit signalShowSeparateWindow(checked);
 }
 
-void splitViewWidget::resetView(bool checked)
-{
-  this->setSplittingPoint(0.5);
-  MoveAndZoomableView::resetView(checked);
+void splitViewWidget::toggleFullScreen(bool checked) 
+{ 
+  Q_UNUSED(checked);
+  emit this->signalToggleFullScreen();
 }
 
-void splitViewWidget::zoomToFit(bool checked)
+void splitViewWidget::resetViewInternal()
 {
-  Q_UNUSED(checked);
-  if (!playlist)
+  this->setSplittingPoint(0.5);
+  MoveAndZoomableView::resetViewInternal();
+}
+
+void splitViewWidget::zoomToFitInternal()
+{
+  if (!this->playlist)
     // The playlist was not initialized yet. Nothing to draw (yet)
     return;
 
   this->setMoveOffset(QPoint(0,0));
 
-  auto item = playlist->getSelectedItems();
+  auto item = this->playlist->getSelectedItems();
 
   if (item[0] == nullptr)
     // We cannot zoom to anything
@@ -1210,9 +1212,12 @@ void splitViewWidget::zoomToFit(bool checked)
       newZoomFactor *= SPLITVIEWWIDGET_ZOOM_STEP_FACTOR;
   }
 
+  if (newZoomFactor < ZOOMINGLIMIT.min || newZoomFactor > ZOOMINGLIMIT.max)
+    return;
+
   // Set new zoom factor and update
   this->setZoomFactor(newZoomFactor);
-  update();
+  this->update();
 }
 
 void splitViewWidget::setViewSplitMode(ViewSplitMode mode, bool setOtherViewIfLinked, bool callUpdate)
@@ -1290,7 +1295,7 @@ void splitViewWidget::currentSelectedItemsChanged(playlistItem *item1, playlistI
       item2->getZoomAndPosition(moveOffset, this->zoomFactor, false);
       item2->getZoomAndPosition(this->getOtherWidget()->moveOffset, this->getOtherWidget()->zoomFactor, getOtherViewValuesFromOtherSlot);
     }
-    DEBUG_LOAD_DRAW("splitViewWidget::currentSelectedItemsChanged restore from item " << item1->getID() << " moveOffset " << this->moveOffset << " zoom " << this->zoomFactor);
+    DEBUG_LOAD_DRAW("splitViewWidget::currentSelectedItemsChanged restore from item " << item1->properties().id << " moveOffset " << this->moveOffset << " zoom " << this->zoomFactor);
   }
 }
 
@@ -1460,7 +1465,7 @@ void splitViewWidget::freezeView(bool freeze)
   }
 }
 
-void splitViewWidget::getViewState(QPoint &offset, double &zoom, double &splitPoint, int &mode) const
+void splitViewWidget::getViewState(QPointF &offset, double &zoom, double &splitPoint, int &mode) const
 {
   offset = this->moveOffset;
   zoom = this->zoomFactor;
@@ -1473,7 +1478,7 @@ void splitViewWidget::getViewState(QPoint &offset, double &zoom, double &splitPo
     mode = 2;
 }
 
-void splitViewWidget::setViewState(const QPoint &offset, double zoom, double splitPoint, int mode)
+void splitViewWidget::setViewState(const QPointF &offset, double zoom, double splitPoint, int mode)
 {
   this->setMoveOffset(offset);
   this->setZoomFactor(zoom);
@@ -1485,14 +1490,6 @@ void splitViewWidget::setViewState(const QPoint &offset, double zoom, double spl
   update();
 }
 
-void splitViewWidget::keyPressEvent(QKeyEvent *event)
-{
-  if (!handleKeyPress(event))
-    // If this widget does not handle the key press event, pass it up to the widget so that
-    // it is propagated to the parent.
-    QWidget::keyPressEvent(event);
-}
-
 void splitViewWidget::onSwipeLeft()
 { 
   playback->nextFrame();
@@ -1560,12 +1557,21 @@ void splitViewWidget::createMenuActions()
     actionSeparateViewLink.setToolTip("Link the second view so that any change in one view is also applied in the other view.");
     actionSeparateViewPlaybackBoth.setToolTip("For performance reasons playback only runs in one (the second) view. Activate this to run playback in both views siultaneously.");
   }
+
+  configureCheckableAction(actionFullScreen, nullptr, "&Fullscreen Mode", false, &splitViewWidget::toggleFullScreen, Qt::CTRL + Qt::Key_F);
+}
+
+void splitViewWidget::addContextMenuActions(QMenu *menu)
+{
+  this->addMenuActions(menu);
+  menu->addSeparator();
+  MoveAndZoomableView::addContextMenuActions(menu);
 }
 
 // Handle the key press event (if this widgets handles it). If not, return false.
 bool splitViewWidget::handleKeyPress(QKeyEvent *event)
 {
-  //qDebug() << QTime::currentTime().toString("hh:mm:ss.zzz")<<"Key: "<< event;
+  DEBUG_LOAD_DRAW(QTime::currentTime().toString("hh:mm:ss.zzz") << "Key: " << event);
 
   int key = event->key();
   bool controlOnly = event->modifiers() == Qt::ControlModifier;
@@ -1576,34 +1582,8 @@ bool splitViewWidget::handleKeyPress(QKeyEvent *event)
       emit signalShowSeparateWindow(false);
     return true;
   }
-  else if (key == Qt::Key_0 && controlOnly)
-  {
-    this->resetView();
-    return true;
-  }
-  else if (key == Qt::Key_9 && controlOnly)
-  {
-    zoomToFit();
-    return true;
-  }
-  else if (key == Qt::Key_Plus && controlOnly)
-  {
-    this->zoom(ZoomMode::IN);
-    return true;
-  }
-  else if (key == Qt::Key_BracketRight && controlOnly)
-  {
-    // This seems to be a bug in the Qt localization routine. On the German keyboard layout this key is returned if Ctrl + is pressed.
-    this->zoom(ZoomMode::IN);
-    return true;
-  }
-  else if (key == Qt::Key_Minus && controlOnly)
-  {
-    this->zoom(ZoomMode::OUT);
-    return true;
-  }
-
-  return false;
+  
+  return MoveAndZoomableView::handleKeyPress(event);
 }
 
 QStringPair splitViewWidget::determineItemNamesToDraw(playlistItem *item1, playlistItem *item2)
@@ -1612,8 +1592,8 @@ QStringPair splitViewWidget::determineItemNamesToDraw(playlistItem *item1, playl
     return QStringPair();
 
   auto sep = QDir::separator();
-  auto name1 = item1->getName().split(sep);
-  auto name2 = item2->getName().split(sep);
+  auto name1 = item1->properties().name.split(sep);
+  auto name2 = item2->properties().name.split(sep);
   if (name1.empty() || name2.empty())
     return QStringPair();
 
@@ -1621,7 +1601,7 @@ QStringPair splitViewWidget::determineItemNamesToDraw(playlistItem *item1, playl
   auto it2 = name2.constEnd() - 1;
   
   if (*it1 != *it2)
-    return QStringPair(*it1, *it2);
+    return QStringPair(item1->properties().name, item2->properties().name);
 
   QStringPair ret = QStringPair(*it1, *it2);
   --it1;
@@ -1765,8 +1745,6 @@ void splitViewWidget::addMenuActions(QMenu *menu)
     drawGridMenu->addAction(&actionGrid[i]);
 
   menu->addAction(&actionZoomBox);
-  MoveAndZoomableView::addMenuActions(menu);
-  menu->addSeparator();
 
   QMenu *separateViewMenu = menu->addMenu("Separate View");
   separateViewMenu->addAction(!isMasterView ? &this->getOtherWidget()->actionSeparateView : &actionSeparateView);
@@ -1774,6 +1752,8 @@ void splitViewWidget::addMenuActions(QMenu *menu)
   separateViewMenu->addAction(!isMasterView ? &this->getOtherWidget()->actionSeparateViewPlaybackBoth : &actionSeparateViewPlaybackBoth);
   separateViewMenu->setToolTipsVisible(true);
 
+  menu->addAction(&this->actionFullScreen);
+
   menu->setToolTipsVisible(true);
 }
 
